<?php
/**
 * The Header for our theme.
 *
 * Displays all of the <head> section and everything up till <div id="content-ts">
 *
 * @package perfect-blogging
 */

?>
<!DOCTYPE html>
<html <?php language_attributes(); ?>>
<head>
  <meta charset="<?php bloginfo( 'charset' ); ?>">
  <meta name="viewport" content="width=device-width">
  <?php wp_head(); ?>
</head>
<body <?php body_class(); ?>>
  <?php if ( function_exists( 'wp_body_open' ) ) { wp_body_open(); }?>
  <div class="<?php if( get_theme_mod( 'perfect_blog_sticky_header', false) != '' || get_theme_mod( 'perfect_blog_responsive_sticky_header',false) != '') { ?> sticky-header"<?php } else { ?>close-sticky <?php } ?>">
    <header role="banner">
      <?php if(get_theme_mod('perfect_blog_preloader_option',true) != '' || get_theme_mod('perfect_blog_responsive_preloader', true) != ''){ ?>
        <div id="loader-wrapper" class="w-100 h-100">
          <div id="loader"></div>
          <div class="loader-section section-left"></div>
          <div class="loader-section section-right"></div>
        </div>
      <?php }?>
      <a class="screen-reader-text skip-link" href="#maincontent"><?php esc_html_e( 'Skip to content', 'perfect-blogging' ); ?></a>
      <div id="header" class="py-1">
        <div class="container">
          <div class="row">
            <div class="logo col-lg-3 col-md-9 col-9">
              <?php if ( has_custom_logo() ) : ?>
                <div class="site-logo"><?php the_custom_logo(); ?></div>
              <?php endif; ?>
              <?php $blog_info = get_bloginfo( 'name' ); ?>
              <?php if ( ! empty( $blog_info ) ) : ?>
                <?php if( get_theme_mod('perfect_blog_site_title',true) != ''){ ?>
                  <?php if ( is_front_page() && is_home() ) : ?>
                    <h1 class="site-title p-0"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
                  <?php else : ?>
                    <p class="site-title mb-0"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
                  <?php endif; ?>
                <?php }?>
              <?php endif; ?>
              <?php
              $description = get_bloginfo( 'description', 'display' );
              if ( $description || is_customize_preview() ) :
                ?>
                <?php if( get_theme_mod('perfect_blog_tagline',true) != ''){ ?>
                  <p class="site-description mb-2">
                    <?php echo esc_html($description); ?>
                  </p>
                <?php }?>
              <?php endif; ?>
            </div>
            <div class="col-lg-7 col-md-3 col-3">
              <?php 
                if(has_nav_menu('primary')){ ?>
                <div class="toggle-menu responsive-menu my-2">
                  <button class="mobiletoggle"><i class="fas fa-bars"></i><span class="screen-reader-text"><?php esc_html_e('Open Menu','perfect-blogging'); ?></span></button>
                </div>
              <?php }?>
              <div id="menu-sidebar" class="nav sidebar">
                <nav id="primary-site-navigation" class="primary-navigation" role="navigation" aria-label="<?php esc_attr_e( 'Top Menu', 'perfect-blogging' ); ?>">
                  <?php 
                    if(has_nav_menu('primary')){ 
                      wp_nav_menu( array( 
                        'theme_location' => 'primary',
                        'container_class' => 'main-menu-navigation clearfix' ,
                        'menu_class' => 'clearfix',
                        'items_wrap' => '<ul id="%1$s" class="%2$s mobile_nav">%3$s</ul>',
                        'fallback_cb' => 'wp_page_menu',
                      ) ); 
                    }
                  ?>
                  <div id="contact-info" class="text-center">
                    <div class="social-icons">
                      <?php if( get_theme_mod( 'perfect_blog_facebook_url') != '') { ?>
                        <a href="<?php echo esc_url( get_theme_mod( 'perfect_blog_facebook_url','' ) ); ?>" class="m-2"><i class="fab fa-facebook-f p-2"></i><span class="screen-reader-text"><?php esc_html_e( 'Facebook','perfect-blogging' );?></span></a>
                      <?php } ?>
                      <?php if( get_theme_mod( 'perfect_blog_twitter_url') != '') { ?>
                        <a href="<?php echo esc_url( get_theme_mod( 'perfect_blog_twitter_url','' ) ); ?>" class="m-2"><i class="fab fa-twitter p-2"></i><span class="screen-reader-text"><?php esc_html_e( 'Twitter','perfect-blogging' );?></span></a>
                      <?php } ?>
                      <?php if( get_theme_mod( 'perfect_blog_skipe_url' ) != '') { ?>
                        <a href="<?php echo esc_url( get_theme_mod( 'perfect_blog_skipe_url','' ) ); ?>" class="m-2"><i class="fab fa-skype p-2"></i><span class="screen-reader-text"><?php esc_html_e( 'Skype','perfect-blogging' );?></span></a>
                      <?php } ?> 
                      <?php if( get_theme_mod( 'perfect_blog_pint_url') != '') { ?>
                        <a href="<?php echo esc_url( get_theme_mod( 'perfect_blog_pint_url','' ) ); ?>" class="m-2"><i class="fab fa-pinterest-p p-2"></i><span class="screen-reader-text"><?php esc_html_e( 'Pinterest','perfect-blogging' );?></span></a>
                      <?php } ?>
                    </div>
                    <?php get_search_form();?>
                  </div>
                  <a href="javascript:void(0)" class="closebtn responsive-menu p-2"><i class="far fa-times-circle"></i><span class="screen-reader-text"><?php esc_html_e('Close Menu','perfect-blogging'); ?></span></a>
                </nav>
              </div>
            </div>
            <div class="social-media col-lg-2 col-md-3 my-3">
              <?php if( get_theme_mod( 'perfect_blog_facebook_url') != '') { ?>
                <a href="<?php echo esc_url( get_theme_mod( 'perfect_blog_facebook_url','' ) ); ?>"><i class="fab fa-facebook-f p-2"></i><span class="screen-reader-text"><?php esc_html_e( 'Facebook','perfect-blogging' );?></span></a>
              <?php } ?>
              <?php if( get_theme_mod( 'perfect_blog_twitter_url') != '') { ?>
                <a href="<?php echo esc_url( get_theme_mod( 'perfect_blog_twitter_url','' ) ); ?>"><i class="fab fa-twitter p-2"></i><span class="screen-reader-text"><?php esc_html_e( 'Twitter','perfect-blogging' );?></span></a>
              <?php } ?>
              <?php if( get_theme_mod( 'perfect_blog_skipe_url' ) != '') { ?>
                <a href="<?php echo esc_url( get_theme_mod( 'perfect_blog_skipe_url','' ) ); ?>"><i class="fab fa-skype p-2"></i><span class="screen-reader-text"><?php esc_html_e( 'Skype','perfect-blogging' );?></span></a>
              <?php } ?> 
              <?php if( get_theme_mod( 'perfect_blog_pint_url') != '') { ?>
                <a href="<?php echo esc_url( get_theme_mod( 'perfect_blog_pint_url','' ) ); ?>"><i class="fab fa-pinterest-p p-2"></i><span class="screen-reader-text"><?php esc_html_e( 'Pinterest','perfect-blogging' );?></span></a>
              <?php } ?>
            </div>
          </div>
        </div>
      </div>
    </header>
  </div>